@@ -21,7 +21,7 @@ class DKConnection():
     def createOrder(self, kitchen, recipe, variation, overrides={}):
         headers = {'content-type': 'application/json', 'authorization': 'bearer ' + self.token}
         url = 'https://%s/v2/order/create/%s/%s/%s' % (self.hostname, kitchen, recipe, variation)
-        payload = {'parameters': overrides}
+        payload = {'parameters': overrides, "schedule" : "now"}
         return requests.put(url, headers=headers, data=json.dumps(payload))
 
     def safeCreateOrder(self, kitchen, recipe, variation, overrides={}, wait_time=10, timeout=100000, test_level=""):
@@ -31,6 +31,7 @@ class DKConnection():
             raise DKOrderException
         order = json.loads(response.text)
         order_id = order['order_id']
+        logger.info(order_id)
         order_run = self.getOrder(kitchen, order_id)
         time.sleep(wait_time)
         time_running = 0
@@ -68,7 +69,7 @@ class DKConnection():
         return DKOrder(json.loads(r.text))
 
     def getOrder(self, kitchen, order_id):
-        return self.OrderInfo(kitchen, order_run_id)
+        return self.OrderInfo(kitchen, order_id)
 
     def TestsFromOrderRun(self, kitchen, order_run_id):
         return self.getOrderRun(kitchen, order_run_id).getTests()
